@@ -1,7 +1,7 @@
 #ifndef STAN_MCMC_HMC_NUTS_BASE_NUTS_HPP
 #define STAN_MCMC_HMC_NUTS_BASE_NUTS_HPP
 
-#include <stan/interface_callbacks/writer/base_writer.hpp>
+#include <stan/callbacks/logger.hpp>
 #include <boost/math/special_functions/fpclassify.hpp>
 #include <stan/math/prim/scal.hpp>
 #include <stan/mcmc/hmc/base_hmc.hpp>
@@ -27,8 +27,38 @@ namespace stan {
           n_leapfrog_(0), divergent_(0), energy_(0) {
       }
 
+      /** 
+       * specialized constructor for specified diag mass matrix
+       */
+      base_nuts(const Model& model, BaseRNG& rng,
+                Eigen::VectorXd& inv_e_metric)
+        : base_hmc<Model, Hamiltonian, Integrator, BaseRNG>(model, rng,
+                                                            inv_e_metric),
+          depth_(0), max_depth_(5), max_deltaH_(1000),
+          n_leapfrog_(0), divergent_(0), energy_(0) {
+      }
+
+      /** 
+       * specialized constructor for specified dense mass matrix
+       */
+      base_nuts(const Model& model, BaseRNG& rng,
+                Eigen::MatrixXd& inv_e_metric)
+        : base_hmc<Model, Hamiltonian, Integrator, BaseRNG>(model, rng,
+                                                            inv_e_metric),
+        depth_(0), max_depth_(5), max_deltaH_(1000),
+        n_leapfrog_(0), divergent_(0), energy_(0) {
+      }
+
       ~base_nuts() {}
 
+      void set_metric(const Eigen::MatrixXd& inv_e_metric) {
+        this->z_.set_metric(inv_e_metric);
+      }
+
+      void set_metric(const Eigen::VectorXd& inv_e_metric) {
+        this->z_.set_metric(inv_e_metric);
+      }
+
       void set_max_depth(int d) {
         if (d > 0)
           max_depth_ = d;
@@ -42,16 +72,14 @@ namespace stan {
       double get_max_delta() { return this->max_deltaH_; }
 
       sample
-      transition(sample& init_sample,
-                 interface_callbacks::writer::base_writer& info_writer,
-                 interface_callbacks::writer::base_writer& error_writer) {
+      transition(sample& init_sample, callbacks::logger& logger) {
         // Initialize the algorithm
         this->sample_stepsize();
 
         this->seed(init_sample.cont_params());
 
         this->hamiltonian_.sample_p(this->z_, this->rand_int_);
-        this->hamiltonian_.init(this->z_, info_writer, error_writer);
+        this->hamiltonian_.init(this->z_, logger);
 
         ps_point z_plus(this->z_);
         ps_point z_minus(z_plus);
@@ -67,7 +95,7 @@ namespace stan {
         double log_sum_weight = 0;  // log(exp(H0 - H0))
         double H0 = this->hamiltonian_.H(this->z_);
         int n_leapfrog = 0;
-        double sum_metro_prob = 1;  // exp(H0 - H0)
+        double sum_metro_prob = 0;
 
         // Build a trajectory until the NUTS criterion is no longer satisfied
         this->depth_ = 0;
@@ -87,7 +115,7 @@ namespace stan {
                            p_sharp_dummy, p_sharp_plus, rho_subtree,
                            H0, 1, n_leapfrog,
                            log_sum_weight_subtree, sum_metro_prob,
-                           info_writer, error_writer);
+                           logger);
             z_plus.ps_point::operator=(this->z_);
           } else {
             this->z_.ps_point::operator=(z_minus);
@@ -96,7 +124,7 @@ namespace stan {
                            p_sharp_dummy, p_sharp_minus, rho_subtree,
                            H0, -1, n_leapfrog,
                            log_sum_weight_subtree, sum_metro_prob,
-                           info_writer, error_writer);
+                           logger);
             z_minus.ps_point::operator=(this->z_);
           }
 
@@ -128,7 +156,7 @@ namespace stan {
         // Compute average acceptance probabilty across entire trajectory,
         // even over subtrees that may have been rejected
         double accept_prob
-          = sum_metro_prob / static_cast<double>(n_leapfrog + 1);
+          = sum_metro_prob / static_cast<double>(n_leapfrog);
 
         this->z_.ps_point::operator=(z_sample);
         this->energy_ = this->hamiltonian_.H(this->z_);
@@ -173,8 +201,7 @@ namespace stan {
        * @param n_leapfrog Summed number of leapfrog evaluations
        * @param log_sum_weight Log of summed weights across trajectory
        * @param sum_metro_prob Summed Metropolis probabilities across trajectory
-       * @param info_writer Stream for information messages
-       * @param error_writer Stream for error messages
+       * @param logger Logger for messages
       */
       bool build_tree(int depth, ps_point& z_propose,
                       Eigen::VectorXd& p_sharp_left,
@@ -182,13 +209,12 @@ namespace stan {
                       Eigen::VectorXd& rho,
                       double H0, double sign, int& n_leapfrog,
                       double& log_sum_weight, double& sum_metro_prob,
-                      interface_callbacks::writer::base_writer& info_writer,
-                      interface_callbacks::writer::base_writer& error_writer) {
+                      callbacks::logger& logger) {
         // Base case
         if (depth == 0) {
           this->integrator_.evolve(this->z_, this->hamiltonian_,
                                    sign * this->epsilon_,
-                                   info_writer, error_writer);
+                                   logger);
           ++n_leapfrog;
 
           double h = this->hamiltonian_.H(this->z_);
@@ -224,7 +250,7 @@ namespace stan {
                        p_sharp_left, p_sharp_dummy, rho_left,
                        H0, sign, n_leapfrog,
                        log_sum_weight_left, sum_metro_prob,
-                       info_writer, error_writer);
+                       logger);
 
         if (!valid_left) return false;
 
@@ -239,7 +265,7 @@ namespace stan {
                        p_sharp_dummy, p_sharp_right, rho_right,
                        H0, sign, n_leapfrog,
                        log_sum_weight_right, sum_metro_prob,
-                       info_writer, error_writer);
+                       logger);
 
         if (!valid_right) return false;
 
