@@ -3,6 +3,7 @@
 
 #include <stan/math/fwd/core.hpp>
 #include <stan/math/prim/scal/fun/constants.hpp>
+#include <stan/math/prim/scal/fun/is_nan.hpp>
 #include <stan/math/prim/scal/fun/value_of.hpp>
 #include <stan/math/prim/scal/meta/likely.hpp>
 #include <cmath>
@@ -13,11 +14,9 @@ namespace stan {
     template<typename T>
     inline fvar<T> fabs(const fvar<T>& x) {
       using std::fabs;
-      using stan::math::NOT_A_NUMBER;
-      using stan::math::value_of;
 
-      if (unlikely(boost::math::isnan(value_of(x.val_))))
-        return fvar<T>(fabs(x.val_), stan::math::NOT_A_NUMBER);
+      if (unlikely(is_nan(value_of(x.val_))))
+        return fvar<T>(fabs(x.val_), NOT_A_NUMBER);
       else if (x.val_ > 0.0)
         return x;
       else if (x.val_ < 0.0)
