@@ -8,7 +8,7 @@ namespace stan {
   namespace math {
 
     /**
-     * Return <code>true</code> if the specified matrix/vector is of
+     * Check if the specified matrix/vector is of
      * non-zero size.
      *
      * Throws a std:invalid_argument otherwise. The message
@@ -20,22 +20,19 @@ namespace stan {
      * @param name Variable name (for error messages)
      * @param y Container to test. This will accept matrices and vectors
      *
-     * @return <code>true</code> if the the specified matrix/vector is
-     * of non-zero size
      * @throw <code>std::invalid_argument</code> if the specified matrix/vector
      *   has zero size
      */
     template <typename T_y>
-    inline bool check_nonzero_size(const char* function,
+    inline void check_nonzero_size(const char* function,
                                    const char* name,
                                    const T_y& y) {
       if (y.size() > 0)
-        return true;
+        return;
 
       invalid_argument(function, name, 0,
                        "has size ",
                        ", but must have a non-zero size");
-      return false;
     }
 
   }
