@@ -10,7 +10,7 @@
 namespace stan {
   namespace math {
     /**
-     * Return <code>true</code> if the specified matrix is a
+     * Check if the specified matrix is a
      * square, symmetric, and positive semi-definite.
      *
      * @tparam T Scalar type of the matrix
@@ -19,25 +19,20 @@ namespace stan {
      * @param name Variable name (for error messages)
      * @param y Matrix to test
      *
-     * @return <code>true</code> if the matrix is a square, symmetric,
-     *   and positive semi-definite.
      * @throw <code>std::invalid_argument</code> if the matrix is not square
      *   or if the matrix is 0x0
      * @throw <code>std::domain_error</code> if the matrix is not symmetric
      *   or if the matrix is not positive semi-definite
      */
     template <typename T_y>
-    inline bool
-    check_spsd_matrix(
-      const char* function,
-      const char* name,
-      const Eigen::Matrix<T_y, Eigen::Dynamic, Eigen::Dynamic>& y
-    ) {
+    inline void
+    check_spsd_matrix(const char* function,
+                      const char* name,
+                  const Eigen::Matrix<T_y, Eigen::Dynamic, Eigen::Dynamic>& y) {
       check_square(function, name, y);
       check_positive_size(function, name, "rows()", y.rows());
       check_symmetric(function, name, y);
       check_pos_semidefinite(function, name, y);
-      return true;
     }
 
   }
