@@ -26,13 +26,12 @@ namespace stan {
     positive_ordered_free(const Eigen::Matrix<T, Eigen::Dynamic, 1>& y) {
       using Eigen::Matrix;
       using Eigen::Dynamic;
-      using stan::math::index_type;
       using std::log;
       typedef typename index_type<Matrix<T, Dynamic, 1> >::type size_type;
 
-      stan::math::check_positive_ordered("stan::math::positive_ordered_free",
-                                         "Positive ordered variable",
-                                         y);
+      check_positive_ordered("stan::math::positive_ordered_free",
+                             "Positive ordered variable",
+                             y);
       size_type k = y.size();
       Matrix<T, Dynamic, 1> x(k);
       if (k == 0)
