@@ -18,13 +18,14 @@ namespace stan {
      * @param m Matrix.
      * @param i Row index (count from 1).
      * @return Specified row of the matrix.
+     * @throw std::out_of_range if i is out of range.
      */
     template <typename T>
     inline
     Eigen::Matrix<T, 1, Eigen::Dynamic>
     row(const Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>& m,
         size_t i) {
-      stan::math::check_row_index("row", "j", m, i);
+      check_row_index("row", "i", m, i);
 
       return m.row(i - 1);
     }
