@@ -30,9 +30,8 @@ namespace stan {
     to_vector(const std::vector<int> & vec) {
       int R = vec.size();
       Eigen::Matrix<double, Eigen::Dynamic, 1> result(R);
-      double* datap = result.data();
       for (int i=0; i < R; i++)
-        datap[i] = vec[i];
+        result(i) = vec[i];
       return result;
     }
 
