@@ -1,7 +1,7 @@
 #ifndef STAN_MATH_PRIM_MAT_META_VALUE_TYPE_HPP
 #define STAN_MATH_PRIM_MAT_META_VALUE_TYPE_HPP
 
-#include <stan/math/prim/scal/meta/value_type.hpp>
+#include <stan/math/prim/arr/meta/value_type.hpp>
 #include <Eigen/Core>
 
 namespace stan {
@@ -17,7 +17,7 @@ namespace stan {
      */
     template <typename T, int R, int C>
     struct value_type<Eigen::Matrix<T, R, C> > {
-      typedef typename Eigen::Matrix<T, R, C>::Scalar type;
+      typedef T type;
     };
 
   }
