@@ -9,21 +9,20 @@ namespace stan {
   namespace math {
 
     /**
-     * Return <code>true</code> if <code>size</code> is positive.
+     * Check if <code>size</code> is positive.
      *
      * @param function Function name (for error messages)
      * @param name Variable name (for error messages)
      * @param expr Expression for the dimension size (for error messages)
      * @param size Size value to check
      *
-     * @return <code>true</code> if <code>size</code> is greater than 0.
      * @throw <code>std::invalid_argument</code> if <code>size</code> is
      *   zero or negative.
      */
-    inline bool check_positive_size(const char* function,
+    inline void check_positive_size(const char* function,
                                     const char* name,
                                     const char* expr,
-                                    const int size) {
+                                    int size) {
       if (size <= 0) {
         std::stringstream msg;
         msg << "; dimension size expression = " << expr;
@@ -32,7 +31,6 @@ namespace stan {
                          "must have a positive size, but is ",
                          msg_str.c_str());
       }
-      return true;
     }
 
   }
