@@ -1,22 +1,23 @@
 #ifndef STAN_MATH_PRIM_SCAL_FUN_LOG1M_EXP_HPP
 #define STAN_MATH_PRIM_SCAL_FUN_LOG1M_EXP_HPP
 
+#include <stan/math/prim/scal/fun/expm1.hpp>
 #include <stan/math/prim/scal/fun/log1m.hpp>
-#include <boost/throw_exception.hpp>
 #include <cmath>
 #include <limits>
-#include <stdexcept>
 
 namespace stan {
   namespace math {
 
     /**
-     * Calculates the log of 1 minus the exponential of the specified
-     * value without overflow log1m_exp(x) = log(1-exp(x)).
+     * Calculates the natural logarithm of one minus the exponential
+     * of the specified value without overflow,
      *
-     * This function is only defined for x<0
+     * <p><code>log1m_exp(x) = log(1-exp(x))</code>
      *
+     * This function is only defined for x < 0
      *
+
        \f[
        \mbox{log1m\_exp}(x) =
        \begin{cases}
@@ -34,12 +35,15 @@ namespace stan {
          \textrm{NaN} & \mbox{if } x = \textrm{NaN}
        \end{cases}
        \f]
+
+     * @param[in] a Argument.
+     * @return natural logarithm of one minus the exponential of the
+     * argument. 
+     *
      */
-    inline double log1m_exp(const double a) {
+    inline double log1m_exp(double a) {
       using std::log;
       using std::exp;
-      using ::expm1;
-
       if (a >= 0)
         return std::numeric_limits<double>::quiet_NaN();
       else if (a > -0.693147)
