@@ -3,7 +3,7 @@
 
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_bounded.hpp>
 #include <stan/math/prim/scal/err/check_finite.hpp>
@@ -58,10 +58,10 @@ namespace stan {
       if (!include_summand<propto, T_prob>::value)
         return 0.0;
 
-      scalar_seq_view<const T_n> n_vec(n);
-      scalar_seq_view<const T_prob> theta_vec(theta);
+      scalar_seq_view<T_n> n_vec(n);
+      scalar_seq_view<T_prob> theta_vec(theta);
       size_t N = max_size(n, theta);
-      OperandsAndPartials<T_prob> operands_and_partials(theta);
+      operands_and_partials<T_prob> ops_partials(theta);
 
       for (size_t n = 0; n < N; n++) {
         const int n_int = value_of(n_vec[n]);
@@ -83,15 +83,15 @@ namespace stan {
         if (!is_constant_struct<T_prob>::value) {
           static const double cutoff = 20.0;
           if (ntheta > cutoff)
-            operands_and_partials.d_x1[n] -= exp_m_ntheta;
+            ops_partials.edge1_.partials_[n] -= exp_m_ntheta;
           else if (ntheta < -cutoff)
-            operands_and_partials.d_x1[n] += sign;
+            ops_partials.edge1_.partials_[n] += sign;
           else
-            operands_and_partials.d_x1[n] += sign * exp_m_ntheta
+            ops_partials.edge1_.partials_[n] += sign * exp_m_ntheta
               / (exp_m_ntheta + 1);
         }
       }
-      return operands_and_partials.value(logp);
+      return ops_partials.build(logp);
     }
 
     template <typename T_n,
