@@ -3,7 +3,7 @@
 
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_bounded.hpp>
 #include <stan/math/prim/scal/err/check_finite.hpp>
@@ -59,10 +59,10 @@ namespace stan {
       if (!include_summand<propto, T_prob>::value)
         return 0.0;
 
-      scalar_seq_view<const T_n> n_vec(n);
-      scalar_seq_view<const T_prob> theta_vec(theta);
+      scalar_seq_view<T_n> n_vec(n);
+      scalar_seq_view<T_prob> theta_vec(theta);
       size_t N = max_size(n, theta);
-      OperandsAndPartials<T_prob> operands_and_partials(theta);
+      operands_and_partials<T_prob> ops_partials(theta);
 
       if (length(theta) == 1) {
         size_t sum = 0;
@@ -74,11 +74,11 @@ namespace stan {
         if (sum == N) {
           logp += N * log(theta_dbl);
           if (!is_constant_struct<T_prob>::value)
-            operands_and_partials.d_x1[0] += N / theta_dbl;
+            ops_partials.edge1_.partials_[0] += N / theta_dbl;
         } else if (sum == 0) {
           logp += N * log1m(theta_dbl);
           if (!is_constant_struct<T_prob>::value)
-            operands_and_partials.d_x1[0] += N / (theta_dbl - 1);
+            ops_partials.edge1_.partials_[0] += N / (theta_dbl - 1);
         } else {
           const T_partials_return log_theta = log(theta_dbl);
           const T_partials_return log1m_theta = log1m(theta_dbl);
@@ -87,8 +87,8 @@ namespace stan {
           logp += (N - sum) * log1m_theta;
 
           if (!is_constant_struct<T_prob>::value) {
-            operands_and_partials.d_x1[0] += sum / theta_dbl;
-            operands_and_partials.d_x1[0] += (N - sum) / (theta_dbl - 1);
+            ops_partials.edge1_.partials_[0] += sum / theta_dbl;
+            ops_partials.edge1_.partials_[0] += (N - sum) / (theta_dbl - 1);
           }
         }
       } else {
@@ -103,13 +103,13 @@ namespace stan {
 
           if (!is_constant_struct<T_prob>::value) {
             if (n_int == 1)
-              operands_and_partials.d_x1[n] += 1.0 / theta_dbl;
+              ops_partials.edge1_.partials_[n] += 1.0 / theta_dbl;
             else
-              operands_and_partials.d_x1[n] += 1.0 / (theta_dbl - 1);
+              ops_partials.edge1_.partials_[n] += 1.0 / (theta_dbl - 1);
           }
         }
       }
-      return operands_and_partials.value(logp);
+      return ops_partials.build(logp);
     }
 
     template <typename T_y, typename T_prob>
