@@ -3,7 +3,7 @@
 
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
@@ -68,23 +68,23 @@ namespace stan {
                              "First prior sample size parameter", alpha,
                              "Second prior sample size parameter", beta);
 
-      scalar_seq_view<const T_n> n_vec(n);
-      scalar_seq_view<const T_N> N_vec(N);
-      scalar_seq_view<const T_size1> alpha_vec(alpha);
-      scalar_seq_view<const T_size2> beta_vec(beta);
+      scalar_seq_view<T_n> n_vec(n);
+      scalar_seq_view<T_N> N_vec(N);
+      scalar_seq_view<T_size1> alpha_vec(alpha);
+      scalar_seq_view<T_size2> beta_vec(beta);
       size_t size = max_size(n, N, alpha, beta);
 
       using std::exp;
       using std::exp;
 
-      OperandsAndPartials<T_size1, T_size2>
-        operands_and_partials(alpha, beta);
+      operands_and_partials<T_size1, T_size2>
+        ops_partials(alpha, beta);
 
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
       for (size_t i = 0; i < stan::length(n); i++) {
         if (value_of(n_vec[i]) <= 0)
-          return operands_and_partials.value(0.0);
+          return ops_partials.build(0.0);
       }
 
       for (size_t i = 0; i < size; i++) {
@@ -134,28 +134,28 @@ namespace stan {
           const T_partials_return g
             = - C * (digamma(mu) - digammaOne + dF[1] / F
                      - digamma(alpha_dbl) + digammaTwo);
-          operands_and_partials.d_x1[i]
+          ops_partials.edge1_.partials_[i]
             += g / Pi;
         }
         if (!is_constant_struct<T_size2>::value) {
           const T_partials_return g
             = - C * (digamma(nu) - digammaOne - dF[4] / F - digamma(beta_dbl)
                      + digammaTwo);
-          operands_and_partials.d_x2[i]
+          ops_partials.edge2_.partials_[i]
             += g / Pi;
         }
       }
 
       if (!is_constant_struct<T_size1>::value) {
         for (size_t i = 0; i < stan::length(alpha); ++i)
-          operands_and_partials.d_x1[i] *= P;
+          ops_partials.edge1_.partials_[i] *= P;
       }
       if (!is_constant_struct<T_size2>::value) {
         for (size_t i = 0; i < stan::length(beta); ++i)
-          operands_and_partials.d_x2[i] *= P;
+          ops_partials.edge2_.partials_[i] *= P;
       }
 
-      return operands_and_partials.value(P);
+      return ops_partials.build(P);
     }
 
   }
