@@ -3,7 +3,7 @@
 
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_bounded.hpp>
 #include <stan/math/prim/scal/err/check_finite.hpp>
@@ -64,9 +64,9 @@ namespace stan {
                              "Population size parameter", N,
                              "Probability parameter", theta);
 
-      scalar_seq_view<const T_n> n_vec(n);
-      scalar_seq_view<const T_N> N_vec(N);
-      scalar_seq_view<const T_prob> theta_vec(theta);
+      scalar_seq_view<T_n> n_vec(n);
+      scalar_seq_view<T_N> N_vec(N);
+      scalar_seq_view<T_prob> theta_vec(theta);
       size_t size = max_size(n, N, theta);
 
       using std::exp;
@@ -74,21 +74,21 @@ namespace stan {
       using std::log;
       using std::exp;
 
-      OperandsAndPartials<T_prob> operands_and_partials(theta);
+      operands_and_partials<T_prob> ops_partials(theta);
 
       // Explicit return for extreme values
       // The gradients are technically ill-defined,
       // but treated as negative infinity
       for (size_t i = 0; i < stan::length(n); i++) {
         if (value_of(n_vec[i]) < 0)
-          return operands_and_partials.value(0.0);
+          return ops_partials.build(0.0);
       }
 
       for (size_t i = 0; i < size; i++) {
         // Explicit results for extreme values
         // The gradients are technically ill-defined, but treated as zero
         if (value_of(n_vec[i]) >= value_of(N_vec[i])) {
-          return operands_and_partials.value(negative_infinity());
+          return ops_partials.build(negative_infinity());
         }
         const T_partials_return n_dbl = value_of(n_vec[i]);
         const T_partials_return N_dbl = value_of(N_vec[i]);
@@ -100,11 +100,11 @@ namespace stan {
         P += log(Pi);
 
         if (!is_constant_struct<T_prob>::value)
-          operands_and_partials.d_x1[i] += pow(theta_dbl, n_dbl)
+          ops_partials.edge1_.partials_[i] += pow(theta_dbl, n_dbl)
             * pow(1-theta_dbl, N_dbl-n_dbl-1) / betafunc / Pi;
       }
 
-      return operands_and_partials.value(P);
+      return ops_partials.build(P);
     }
 
   }
