@@ -3,7 +3,7 @@
 
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_finite.hpp>
 #include <stan/math/prim/scal/err/check_not_nan.hpp>
@@ -55,12 +55,12 @@ namespace stan {
       check_finite(function, "Location parameter", mu);
       check_positive_finite(function, "Scale parameter", sigma);
 
-      OperandsAndPartials<T_y, T_loc, T_scale>
-        operands_and_partials(y, mu, sigma);
+      operands_and_partials<T_y, T_loc, T_scale>
+        ops_partials(y, mu, sigma);
 
-      scalar_seq_view<const T_y> y_vec(y);
-      scalar_seq_view<const T_loc> mu_vec(mu);
-      scalar_seq_view<const T_scale> sigma_vec(sigma);
+      scalar_seq_view<T_y> y_vec(y);
+      scalar_seq_view<T_loc> mu_vec(mu);
+      scalar_seq_view<T_scale> sigma_vec(sigma);
       size_t N = max_size(y, mu, sigma);
 
       for (size_t n = 0; n < N; n++) {
@@ -86,23 +86,23 @@ namespace stan {
 
         if (y_dbl < mu_dbl) {
           if (!is_constant_struct<T_y>::value)
-            operands_and_partials.d_x1[n] += inv_sigma * cdf;
+            ops_partials.edge1_.partials_[n] += inv_sigma * cdf;
           if (!is_constant_struct<T_loc>::value)
-            operands_and_partials.d_x2[n] -= inv_sigma * cdf;
+            ops_partials.edge2_.partials_[n] -= inv_sigma * cdf;
           if (!is_constant_struct<T_scale>::value)
-            operands_and_partials.d_x3[n] -= scaled_diff * inv_sigma  * cdf;
+            ops_partials.edge3_.partials_[n] -= scaled_diff * inv_sigma  * cdf;
         } else {
           const T_partials_return rep_deriv = cdf * inv_sigma
             / (2.0 * exp_scaled_diff - 1.0);
           if (!is_constant_struct<T_y>::value)
-            operands_and_partials.d_x1[n] += rep_deriv;
+            ops_partials.edge1_.partials_[n] += rep_deriv;
           if (!is_constant_struct<T_loc>::value)
-            operands_and_partials.d_x2[n] -= rep_deriv;
+            ops_partials.edge2_.partials_[n] -= rep_deriv;
           if (!is_constant_struct<T_scale>::value)
-            operands_and_partials.d_x3[n] -= rep_deriv * scaled_diff;
+            ops_partials.edge3_.partials_[n] -= rep_deriv * scaled_diff;
         }
       }
-      return operands_and_partials.value(cdf);
+      return ops_partials.build(cdf);
     }
 
   }
