@@ -1,7 +1,7 @@
 #ifndef STAN_MATH_PRIM_SCAL_PROB_GAMMA_CDF_HPP
 #define STAN_MATH_PRIM_SCAL_PROB_GAMMA_CDF_HPP
 
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_greater_or_equal.hpp>
 #include <stan/math/prim/scal/err/check_less_or_equal.hpp>
@@ -60,27 +60,27 @@ namespace stan {
       T_partials_return P(1.0);
 
       check_positive_finite(function, "Shape parameter", alpha);
-      check_positive_finite(function, "Scale parameter", beta);
+      check_positive_finite(function, "Inverse scale parameter", beta);
       check_not_nan(function, "Random variable", y);
       check_nonnegative(function, "Random variable", y);
       check_consistent_sizes(function,
                              "Random variable", y,
                              "Shape parameter", alpha,
-                             "Scale Parameter", beta);
+                             "Inverse scale parameter", beta);
 
-      scalar_seq_view<const T_y> y_vec(y);
-      scalar_seq_view<const T_shape> alpha_vec(alpha);
-      scalar_seq_view<const T_inv_scale> beta_vec(beta);
+      scalar_seq_view<T_y> y_vec(y);
+      scalar_seq_view<T_shape> alpha_vec(alpha);
+      scalar_seq_view<T_inv_scale> beta_vec(beta);
       size_t N = max_size(y, alpha, beta);
 
-      OperandsAndPartials<T_y, T_shape, T_inv_scale>
-        operands_and_partials(y, alpha, beta);
+      operands_and_partials<T_y, T_shape, T_inv_scale>
+        ops_partials(y, alpha, beta);
 
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
       for (size_t i = 0; i < stan::length(y); i++) {
         if (value_of(y_vec[i]) == 0)
-          return operands_and_partials.value(0.0);
+          return ops_partials.build(0.0);
       }
 
       using boost::math::tgamma;
@@ -116,31 +116,31 @@ namespace stan {
         P *= Pn;
 
         if (!is_constant_struct<T_y>::value)
-          operands_and_partials.d_x1[n] += beta_dbl * exp(-beta_dbl * y_dbl)
+          ops_partials.edge1_.partials_[n] += beta_dbl * exp(-beta_dbl * y_dbl)
             * pow(beta_dbl * y_dbl, alpha_dbl-1) / tgamma(alpha_dbl) / Pn;
         if (!is_constant_struct<T_shape>::value)
-          operands_and_partials.d_x2[n]
+          ops_partials.edge2_.partials_[n]
             -= grad_reg_inc_gamma(alpha_dbl, beta_dbl
                                   * y_dbl, gamma_vec[n],
                                   digamma_vec[n]) / Pn;
         if (!is_constant_struct<T_inv_scale>::value)
-          operands_and_partials.d_x3[n] += y_dbl  * exp(-beta_dbl * y_dbl)
+          ops_partials.edge3_.partials_[n] += y_dbl  * exp(-beta_dbl * y_dbl)
             * pow(beta_dbl * y_dbl, alpha_dbl-1) / tgamma(alpha_dbl) / Pn;
       }
 
       if (!is_constant_struct<T_y>::value) {
         for (size_t n = 0; n < stan::length(y); ++n)
-          operands_and_partials.d_x1[n] *= P;
+          ops_partials.edge1_.partials_[n] *= P;
       }
       if (!is_constant_struct<T_shape>::value) {
         for (size_t n = 0; n < stan::length(alpha); ++n)
-          operands_and_partials.d_x2[n] *= P;
+          ops_partials.edge2_.partials_[n] *= P;
       }
       if (!is_constant_struct<T_inv_scale>::value) {
         for (size_t n = 0; n < stan::length(beta); ++n)
-          operands_and_partials.d_x3[n] *= P;
+          ops_partials.edge3_.partials_[n] *= P;
       }
-      return operands_and_partials.value(P);
+      return ops_partials.build(P);
     }
 
   }
