@@ -3,7 +3,7 @@
 
 #include <boost/random/exponential_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_finite.hpp>
 #include <stan/math/prim/scal/err/check_not_nan.hpp>
@@ -54,12 +54,12 @@ namespace stan {
       if (!include_summand<propto, T_y, T_loc, T_scale>::value)
         return 0.0;
 
-      OperandsAndPartials<T_y, T_loc, T_scale>
-        operands_and_partials(y, mu, sigma);
+      operands_and_partials<T_y, T_loc, T_scale>
+        ops_partials(y, mu, sigma);
 
-      scalar_seq_view<const T_y> y_vec(y);
-      scalar_seq_view<const T_loc> mu_vec(mu);
-      scalar_seq_view<const T_scale> sigma_vec(sigma);
+      scalar_seq_view<T_y> y_vec(y);
+      scalar_seq_view<T_loc> mu_vec(mu);
+      scalar_seq_view<T_scale> sigma_vec(sigma);
       size_t N = max_size(y, mu, sigma);
 
       VectorBuilder<true, T_partials_return, T_scale> inv_sigma(length(sigma));
@@ -108,19 +108,19 @@ namespace stan {
           logp -= 2.0 * log1p(exp_m_y_minus_mu_div_sigma);
 
         if (!is_constant_struct<T_y>::value)
-          operands_and_partials.d_x1[n]
+          ops_partials.edge1_.partials_[n]
             += (2 * inv_1p_exp_y_minus_mu_div_sigma - 1) * inv_sigma[n];
         if (!is_constant_struct<T_loc>::value)
-          operands_and_partials.d_x2[n] +=
+          ops_partials.edge2_.partials_[n] +=
             (1 - 2 * exp_mu_div_sigma[n] / (exp_mu_div_sigma[n]
                                             + exp_y_div_sigma[n]))
             * inv_sigma[n];
         if (!is_constant_struct<T_scale>::value)
-          operands_and_partials.d_x3[n] +=
+          ops_partials.edge3_.partials_[n] +=
             ((1 - 2 * inv_1p_exp_y_minus_mu_div_sigma)
              *y_minus_mu*inv_sigma[n] - 1) * inv_sigma[n];
       }
-      return operands_and_partials.value(logp);
+      return ops_partials.build(logp);
     }
 
     template <typename T_y, typename T_loc, typename T_scale>
