@@ -3,7 +3,7 @@
 
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/meta/scalar_seq_view.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_finite.hpp>
@@ -46,12 +46,12 @@ namespace stan {
                              "Location parameter", mu,
                              "Scale parameter", sigma);
 
-      OperandsAndPartials<T_y, T_loc, T_scale>
-        operands_and_partials(y, mu, sigma);
+      operands_and_partials<T_y, T_loc, T_scale>
+        ops_partials(y, mu, sigma);
 
-      scalar_seq_view<const T_y> y_vec(y);
-      scalar_seq_view<const T_loc> mu_vec(mu);
-      scalar_seq_view<const T_scale> sigma_vec(sigma);
+      scalar_seq_view<T_y> y_vec(y);
+      scalar_seq_view<T_loc> mu_vec(mu);
+      scalar_seq_view<T_scale> sigma_vec(sigma);
       size_t N = max_size(y, mu, sigma);
       double log_half = std::log(0.5);
 
@@ -83,15 +83,15 @@ namespace stan {
             : SQRT_TWO_OVER_PI * exp(-scaled_diff * scaled_diff)
             / one_m_erf / sigma_dbl;
           if (!is_constant_struct<T_y>::value)
-            operands_and_partials.d_x1[n] -= rep_deriv_div_sigma;
+            ops_partials.edge1_.partials_[n] -= rep_deriv_div_sigma;
           if (!is_constant_struct<T_loc>::value)
-            operands_and_partials.d_x2[n] += rep_deriv_div_sigma;
+            ops_partials.edge2_.partials_[n] += rep_deriv_div_sigma;
           if (!is_constant_struct<T_scale>::value)
-            operands_and_partials.d_x3[n] += rep_deriv_div_sigma
+            ops_partials.edge3_.partials_[n] += rep_deriv_div_sigma
               * scaled_diff * SQRT_2;
         }
       }
-      return operands_and_partials.value(ccdf_log);
+      return ops_partials.build(ccdf_log);
     }
 
   }
