@@ -15,8 +15,8 @@ namespace stan {
 
     template <class RNG>
     inline double
-    normal_rng(const double mu,
-               const double sigma,
+    normal_rng(double mu,
+               double sigma,
                RNG& rng) {
       using boost::variate_generator;
       using boost::normal_distribution;
