@@ -3,7 +3,7 @@
 
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_less.hpp>
 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
@@ -48,8 +48,8 @@ namespace stan {
       if (!include_summand<propto, T_rate>::value)
         return 0.0;
 
-      scalar_seq_view<const T_n> n_vec(n);
-      scalar_seq_view<const T_rate> lambda_vec(lambda);
+      scalar_seq_view<T_n> n_vec(n);
+      scalar_seq_view<T_rate> lambda_vec(lambda);
       size_t size = max_size(n, lambda);
 
       for (size_t i = 0; i < size; i++)
@@ -59,7 +59,7 @@ namespace stan {
         if (lambda_vec[i] == 0 && n_vec[i] != 0)
           return LOG_ZERO;
 
-      OperandsAndPartials<T_rate> operands_and_partials(lambda);
+      operands_and_partials<T_rate> ops_partials(lambda);
 
       for (size_t i = 0; i < size; i++) {
         if (!(lambda_vec[i] == 0 && n_vec[i] == 0)) {
@@ -71,10 +71,10 @@ namespace stan {
         }
 
         if (!is_constant_struct<T_rate>::value)
-          operands_and_partials.d_x1[i]
+          ops_partials.edge1_.partials_[i]
             += n_vec[i] / value_of(lambda_vec[i]) - 1.0;
       }
-      return operands_and_partials.value(logp);
+      return ops_partials.build(logp);
     }
 
     template <typename T_n,
