@@ -3,7 +3,7 @@
 
 #include <boost/random/uniform_real_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
 #include <stan/math/prim/scal/err/check_not_nan.hpp>
@@ -46,10 +46,10 @@ namespace stan {
                              "Random variable", y,
                              "Scale parameter", sigma);
 
-      OperandsAndPartials<T_y, T_scale> operands_and_partials(y, sigma);
+      operands_and_partials<T_y, T_scale> ops_partials(y, sigma);
 
-      scalar_seq_view<const T_y> y_vec(y);
-      scalar_seq_view<const T_scale> sigma_vec(sigma);
+      scalar_seq_view<T_y> y_vec(y);
+      scalar_seq_view<T_scale> sigma_vec(sigma);
       size_t N = max_size(y, sigma);
 
       VectorBuilder<true, T_partials_return, T_scale> inv_sigma(length(sigma));
@@ -75,13 +75,13 @@ namespace stan {
         const T_partials_return exp_div_1m_exp = exp_val / (1.0 - exp_val);
 
         if (!is_constant_struct<T_y>::value)
-          operands_and_partials.d_x1[n] += y_dbl * inv_sigma_sqr
+          ops_partials.edge1_.partials_[n] += y_dbl * inv_sigma_sqr
             * exp_div_1m_exp * cdf;
         if (!is_constant_struct<T_scale>::value)
-          operands_and_partials.d_x2[n] -= y_sqr * inv_sigma_sqr
+          ops_partials.edge2_.partials_[n] -= y_sqr * inv_sigma_sqr
             * inv_sigma[n] * exp_div_1m_exp * cdf;
       }
-      return operands_and_partials.value(cdf);
+      return ops_partials.build(cdf);
     }
 
   }
