@@ -3,7 +3,7 @@
 
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
 #include <stan/math/prim/scal/err/check_not_nan.hpp>
@@ -53,19 +53,19 @@ namespace stan {
                              "Degrees of freedom parameter", nu,
                              "Scale parameter", s);
 
-      scalar_seq_view<const T_y> y_vec(y);
-      scalar_seq_view<const T_dof> nu_vec(nu);
-      scalar_seq_view<const T_scale> s_vec(s);
+      scalar_seq_view<T_y> y_vec(y);
+      scalar_seq_view<T_dof> nu_vec(nu);
+      scalar_seq_view<T_scale> s_vec(s);
       size_t N = max_size(y, nu, s);
 
-      OperandsAndPartials<T_y, T_dof, T_scale>
-        operands_and_partials(y, nu, s);
+      operands_and_partials<T_y, T_dof, T_scale>
+        ops_partials(y, nu, s);
 
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
       for (size_t i = 0; i < stan::length(y); i++) {
         if (value_of(y_vec[i]) == 0)
-          return operands_and_partials.value(negative_infinity());
+          return ops_partials.build(negative_infinity());
       }
 
       using std::exp;
@@ -108,10 +108,10 @@ namespace stan {
         P += log(Pn);
 
         if (!is_constant_struct<T_y>::value)
-          operands_and_partials.d_x1[n] += half_nu_s2_overx_dbl * y_inv_dbl
+          ops_partials.edge1_.partials_[n] += half_nu_s2_overx_dbl * y_inv_dbl
             * gamma_p_deriv / Pn;
         if (!is_constant_struct<T_dof>::value)
-          operands_and_partials.d_x2[n]
+          ops_partials.edge2_.partials_[n]
             += (0.5 * grad_reg_inc_gamma(half_nu_dbl,
                                          half_nu_s2_overx_dbl,
                                          gamma_vec[n],
@@ -119,10 +119,10 @@ namespace stan {
                 - half_s2_overx_dbl * gamma_p_deriv)
             / Pn;
         if (!is_constant_struct<T_scale>::value)
-          operands_and_partials.d_x3[n] += - 2.0 * half_nu_dbl * s_dbl
+          ops_partials.edge3_.partials_[n] += - 2.0 * half_nu_dbl * s_dbl
             * y_inv_dbl * gamma_p_deriv / Pn;
       }
-      return operands_and_partials.value(P);
+      return ops_partials.build(P);
     }
 
   }
