@@ -3,7 +3,7 @@
 
 #include <stan/math/prim/scal/meta/is_constant_struct.hpp>
 #include <stan/math/prim/scal/meta/partials_return_type.hpp>
-#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>
+#include <stan/math/prim/scal/meta/operands_and_partials.hpp>
 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
 #include <stan/math/prim/scal/err/check_finite.hpp>
 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
@@ -24,7 +24,7 @@ namespace stan {
   namespace math {
 
     /**
-     * Returns the Weibull cumulative distribution function for the given 
+     * Returns the Weibull cumulative distribution function for the given
      * location and scale. Given containers of matching sizes, returns the
      * product of probabilities.
      *
@@ -35,7 +35,7 @@ namespace stan {
      * @param alpha shape parameter
      * @param sigma scale parameter
      * @return probability or product of probabilities
-     * @throw std::domain_error if y is negative, alpha sigma is nonpositive 
+     * @throw std::domain_error if y is negative, alpha sigma is nonpositive
      */
     template <typename T_y, typename T_shape, typename T_scale>
     typename return_type<T_y, T_shape, T_scale>::type
@@ -59,12 +59,12 @@ namespace stan {
       check_positive_finite(function, "Shape parameter", alpha);
       check_positive_finite(function, "Scale parameter", sigma);
 
-      OperandsAndPartials<T_y, T_shape, T_scale>
-        operands_and_partials(y, alpha, sigma);
+      operands_and_partials<T_y, T_shape, T_scale>
+        ops_partials(y, alpha, sigma);
 
-      scalar_seq_view<const T_y> y_vec(y);
-      scalar_seq_view<const T_scale> sigma_vec(sigma);
-      scalar_seq_view<const T_shape> alpha_vec(alpha);
+      scalar_seq_view<T_y> y_vec(y);
+      scalar_seq_view<T_scale> sigma_vec(sigma);
+      scalar_seq_view<T_shape> alpha_vec(alpha);
       size_t N = max_size(y, sigma, alpha);
       for (size_t n = 0; n < N; n++) {
         const T_partials_return y_dbl = value_of(y_vec[n]);
@@ -78,26 +78,27 @@ namespace stan {
 
         const T_partials_return rep_deriv = exp_ * pow_ / cdf_;
         if (!is_constant_struct<T_y>::value)
-          operands_and_partials.d_x1[n] += rep_deriv * alpha_dbl / y_dbl;
+          ops_partials.edge1_.partials_[n] += rep_deriv * alpha_dbl / y_dbl;
         if (!is_constant_struct<T_shape>::value)
-          operands_and_partials.d_x2[n] += rep_deriv * log(y_dbl / sigma_dbl);
+          ops_partials.edge2_.partials_[n]
+            += rep_deriv * log(y_dbl / sigma_dbl);
         if (!is_constant_struct<T_scale>::value)
-          operands_and_partials.d_x3[n] -= rep_deriv * alpha_dbl / sigma_dbl;
+          ops_partials.edge3_.partials_[n] -= rep_deriv * alpha_dbl / sigma_dbl;
       }
 
       if (!is_constant_struct<T_y>::value) {
         for (size_t n = 0; n < stan::length(y); ++n)
-          operands_and_partials.d_x1[n] *= cdf;
+          ops_partials.edge1_.partials_[n] *= cdf;
       }
       if (!is_constant_struct<T_shape>::value) {
         for (size_t n = 0; n < stan::length(alpha); ++n)
-          operands_and_partials.d_x2[n] *= cdf;
+          ops_partials.edge2_.partials_[n] *= cdf;
       }
       if (!is_constant_struct<T_scale>::value) {
         for (size_t n = 0; n < stan::length(sigma); ++n)
-          operands_and_partials.d_x3[n] *= cdf;
+          ops_partials.edge3_.partials_[n] *= cdf;
       }
-      return operands_and_partials.value(cdf);
+      return ops_partials.build(cdf);
     }
 
   }
