@@ -4,6 +4,8 @@
 #include <stan/math/rev/core.hpp>
 #include <stan/math/prim/arr/fun/value_of.hpp>
 #include <iostream>
+#include <sstream>
+#include <string>
 #include <vector>
 
 namespace stan {
@@ -19,12 +21,21 @@ namespace stan {
      */
     template <typename F>
     class ode_system {
+    private:
       const F& f_;
       const std::vector<double> theta_;
       const std::vector<double>& x_;
       const std::vector<int>& x_int_;
       std::ostream* msgs_;
 
+      std::string error_msg(size_t y_size, size_t dy_dt_size) const {
+        std::stringstream msg;
+        msg << "ode_system: size of state vector y (" << y_size << ")"
+            << " and derivative vector dy_dt (" << dy_dt_size << ")"
+            << " in the ODE functor do not match in size.";
+        return msg.str();
+      }
+
     public:
       /**
        * Construct an ODE model with the specified base ODE system,
@@ -48,9 +59,14 @@ namespace stan {
        * @param[in] y state of the ode system at time t.
        * @param[out] dy_dt ODE RHS
        */
+      template <typename Derived1>
       inline void operator()(double t, const std::vector<double>& y,
-                             std::vector<double>& dy_dt) const {
-        dy_dt = f_(t, y, theta_, x_, x_int_, msgs_);
+                             Eigen::MatrixBase<Derived1>& dy_dt) const {
+        const std::vector<double> dy_dt_vec = f_(t, y, theta_, x_, x_int_,
+                                                 msgs_);
+        if (unlikely(y.size() != dy_dt_vec.size()))
+          throw std::runtime_error(error_msg(y.size(), dy_dt_vec.size()));
+        dy_dt = Eigen::Map<const Eigen::VectorXd>(&dy_dt_vec[0], y.size());
       }
 
       /**
@@ -64,9 +80,9 @@ namespace stan {
        * @param[out] Jy Jacobian of ODE RHS wrt to y.
        */
       template <typename Derived1, typename Derived2>
-      void jacobian(double t, const std::vector<double>& y,
-                    Eigen::MatrixBase<Derived1>& dy_dt,
-                    Eigen::MatrixBase<Derived2>& Jy) const {
+      inline void jacobian(double t, const std::vector<double>& y,
+                           Eigen::MatrixBase<Derived1>& dy_dt,
+                           Eigen::MatrixBase<Derived2>& Jy) const {
         using Eigen::Matrix;
         using Eigen::Map;
         using Eigen::RowVectorXd;
@@ -77,6 +93,8 @@ namespace stan {
           start_nested();
           vector<var> y_var(y.begin(), y.end());
           vector<var> dy_dt_var = f_(t, y_var, theta_, x_, x_int_, msgs_);
+          if (unlikely(y.size() != dy_dt_var.size()))
+            throw std::runtime_error(error_msg(y.size(), dy_dt_var.size()));
           for (size_t i = 0; i < dy_dt_var.size(); ++i) {
             dy_dt(i) = dy_dt_var[i].val();
             set_zero_all_adjoints_nested();
@@ -103,10 +121,10 @@ namespace stan {
        * @param[out] Jtheta Jacobian of ODE RHS wrt to theta.
        */
       template <typename Derived1, typename Derived2>
-      void jacobian(double t, const std::vector<double>& y,
-                    Eigen::MatrixBase<Derived1>& dy_dt,
-                    Eigen::MatrixBase<Derived2>& Jy,
-                    Eigen::MatrixBase<Derived2>& Jtheta) const {
+      inline void jacobian(double t, const std::vector<double>& y,
+                           Eigen::MatrixBase<Derived1>& dy_dt,
+                           Eigen::MatrixBase<Derived2>& Jy,
+                           Eigen::MatrixBase<Derived2>& Jtheta) const {
         using Eigen::Dynamic;
         using Eigen::Map;
         using Eigen::Matrix;
@@ -123,6 +141,8 @@ namespace stan {
           z_var.insert(z_var.end(), y_var.begin(), y_var.end());
           z_var.insert(z_var.end(), theta_var.begin(), theta_var.end());
           vector<var> dy_dt_var = f_(t, y_var, theta_var, x_, x_int_, msgs_);
+          if (unlikely(y.size() != dy_dt_var.size()))
+            throw std::runtime_error(error_msg(y.size(), dy_dt_var.size()));
           for (size_t i = 0; i < dy_dt_var.size(); ++i) {
             dy_dt(i) = dy_dt_var[i].val();
             set_zero_all_adjoints_nested();
