@@ -12,19 +12,19 @@ namespace stan {
       class modified_bessel_second_kind_dv_vari : public op_dv_vari {
       public:
         modified_bessel_second_kind_dv_vari(int a, vari* bvi) :
-          op_dv_vari(stan::math::modified_bessel_second_kind(a, bvi->val_),
+          op_dv_vari(modified_bessel_second_kind(a, bvi->val_),
                      a, bvi) {
         }
         void chain() {
           bvi_->adj_ -= adj_
-            * (ad_ * stan::math::modified_bessel_second_kind(ad_, bvi_->val_)
+            * (ad_ * modified_bessel_second_kind(ad_, bvi_->val_)
                / bvi_->val_
-               + stan::math::modified_bessel_second_kind(ad_ - 1, bvi_->val_));
+               + modified_bessel_second_kind(ad_ - 1, bvi_->val_));
         }
       };
     }
 
-    inline var modified_bessel_second_kind(const int& v,
+    inline var modified_bessel_second_kind(int v,
                                            const var& a) {
       return var(new modified_bessel_second_kind_dv_vari(v, a.vi_));
     }
